@@ -2,4 +2,5 @@ from .base import BaseResponse
 
 class IsMeetingRunningResponse(BaseResponse):
     def is_meeting_running(self):
-        return self.get_text("running") == "true" or self.get_text("running")
\ No newline at end of file
+        field = self.get_field("running")
+        return field == "true" or (isinstance(field, bool) and field)
\ No newline at end of file
